ConeBurst class

Inheritance

Constructors

ConeBurst({double angle = -pi / 2, double spread = pi / 4, double minSpeed = 100.0, double maxSpeed = 300.0})
const

Properties

angle double
Center direction of cone in radians. Default: straight up (-π/2).
final
hashCode int
The hash code for this object.
no setterinherited
maxSpeed double
final
minSpeed double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spread double
Half-angle of cone in radians. e.g. π/4 = 45° cone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveVelocity(int index, int total, Random rng) Offset
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited