CustomBurst class

Inheritance

Constructors

CustomBurst(Offset velocityBuilder(int index, int total))
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
velocityBuilder Offset Function(int index, int total)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveVelocity(int index, int total, Random rng) Offset
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited