DirectionalBurst class

Inheritance

Constructors

DirectionalBurst({double angle = -pi / 2, double spreadVariance = 0.2, double minSpeed = 100.0, double maxSpeed = 300.0})
const

Properties

angle double
Direction in radians. Default: straight up (-π/2).
final
hashCode int
The hash code for this object.
no setterinherited
maxSpeed double
final
minSpeed double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadVariance double
Random variance added to angle per particle (radians).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveVelocity(int index, int total, Random rng) Offset
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited