RadialBurst class

Inheritance

Constructors

RadialBurst({double minSpeed = 100.0, double maxSpeed = 300.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxSpeed double
final
minSpeed double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveVelocity(int index, int total, Random rng) Offset
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited