ParticleInteraction class

Inheritance

Constructors

ParticleInteraction({Key? key, bool onTapAnimation = true, double awayRadius = 100, Duration awayAnimationDuration = const Duration(milliseconds: 600), Curve awayAnimationCurve = Curves.easeIn, bool enableHover = false, double hoverRadius = 80})
Creates touch and hover interaction with a particle engine.
ParticleInteraction.none({Key? key, bool onTapAnimation = false, double awayRadius = 0, Duration awayAnimationDuration = Duration.zero, Curve awayAnimationCurve = Curves.easeIn, bool enableHover = false, double hoverRadius = 0})

Properties

awayAnimationCurve → Curve
Define the Curve of movement away from the cursor/gesture.
final
awayAnimationDuration → Duration
Define the length of time that movement caused by a gesture will occur.
final
awayRadius → double
Define the radius of a cursor/gesture.
final
enableHover → bool
Toggle interactions with particles from a cursor.
final
hashCode → int
The hash code for this object.
no setterinherited
hoverRadius → double
Unused, but implemented in the original package.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTapAnimation → bool
Toggle interactions with particles with touch controls.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ _InteractivityState
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _InteractivityState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited